<?php
/**
* Base class of all analyser
* @author	 Ulf Wendel <ulf@redsys.de>
* @version 0.2alpha
* @since 	 0.2alpha
*/
class PhpdocAnalyserObject extends PhpdocObject {

	/**
	* Flag indicating wheter to show status messages or not
	* @var	bool	$flagoutput	(default: false)
	* @see	MyOutl()
	*/
	var $flagOutput = false;

	/**
	* Array of classes returned by the parser
	* @var	array	$classes
	* @see	setClasses()
	*/
	var $classes = array();
	
	/**
	* Mapping from classnames to filenames returned by the parser
	* @var	array	$classnamesToFilenames
	* @see	setClassnamesToFilenames()
	*/
	var $classnamesToFilenames = array();
	
	/**
	* @var	array	$classTree
	* @see	buildClasstree()
	*/
	var $classTree = array();
	
	/**
	* Initializes the analyser with the class data
	* @param	array	$classes
	* @return	bool	$ok
	* @throws	runtime_wrongparam	
	* @see		classes
	* @access	public
	*/
	function setClasses($classes) {
		if (!is_array($classes)) {
			$this->err = new exception_runtime_wrongparam("No classdata given.", 1, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return false;
		}
		
		$this->classes = $classes;
		return true;
	} // end func setClasses
	
	/**
	* Initializes the analyser with the classname to filename mapping array
	* @param	array	$classnamesToFilenames
	* @return	bool	$ok
	* @throws	runtime_wrongparam
	* @see		classnamesToFilenames
	* @access	public
	*/
	function setClassnamesToFilenames($classnamesToFilenames) {
		if (!is_array($classnamesToFilenames)) {
			$this->err = new exception_runtime_wrongparam("No classname to filename mapping array given.", 2, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return false;
		}
		
		$this->classnamesToFilenames = $classnamesToFilenames;
		return true;
	} // end func setClassnamesToFilenames
	
	/**
	* Sets the Output Flag
	* If set to true the Analyser prints some status messages
	* @param	bool	$flagOutput
	* @access	public
	* @see		flagOutput
	*/
	function setFlagOutput($flagOutput) {
		$flagOutput = ($flagOutput) ? true : false;
	} // end func setFlagOutput
	
	/**
	* Start the analyser
	* @abstract
	*/
	function analyse() {
		die();
	} // end func analyse
	
	/**
	* Wrapper to outl()
	* Prints the message if flagOutput it set to true
	* @brother outl()
	*/
	function MyOutl($message) {
		if (false == $this->flagOutput)
			return;
		$this->outl($message);
	} // end func MyOutl
	
} // end class PhpdocAnalyserObject
?>