<?php
/**
* Common base class of all phpdoc classes
*
* As a kind of common base class PhpdocObject holds 
* configuration values (e.g. error handling) and debugging
* methods (e.g. introspection()). It does not have a constructor,
* so you can always inheritig Phpdoc classes from this 
* class without any trouble.
*  
* @author		Ulf Wendel <ulf@redsys.de>
* @version 	0.2
*/
class PhpdocObject {

	/**
	* How to handle errors? 
	*
	* Print and stop execution (true) or just save the exception 
	* in the instance variable $err (false)?
	* @var		bool		$AUTO_HANDLE_ERRORS
	* @access	public
	*/
	var $AUTO_HANDLE_ERRORS = true;

	/**
	* Line break used by introspection()
	* @var	string	$CR_HTML	line break "\\n"
	* @see	introspection()
	*/
	var $CR_HTML = "\n";
	
	/** 
	* Variable containing the latest exception object
	* 
	* Of course there's only an object if there's an exception somewhere...
	* 
	* @var		object exception	$err
	* @access	public
	*/
	var $err;

	/**
	* Returns an exception object representing the latest error or false.
	* @return	object	exception  $exception
	* @access	public
	*/
	function getError() {
		if (is_object($this->err))
			return $this->err;
		return false;
	} // end func getError
	
	/**
	* Print a string and flushes the output buffer
	* @param	string 	$message
	*/
	function out($message) {
		print $message;
		flush();
	} // end func out
	
	/**
	* Print a string, the specified HTML line break sign and flushes the output buffer
	* @param	string 	$message
	*/
	function outl($message) {
		print $message.$this->CR_HTML;
		flush();
	} // end func outl
	
	/**
	* Dumps Objects and Arrays.
	* 
	* Use this function to get an idea of the internal datastructures used. 
	* The function dumps arrays and objects. It renders the content in 
	* an HTML table. Play with it, you'll see it's very helpful
	* for debugging.
	* 
	* @param	string	$title	Optional title used in the HTML Table
	* @param	mixed		$data		Optional array or object that you want to dump. 
	* 												Fallback to $this.
	* @param	bool		$userfunction	Optional flag. If set to false userfunction
	*													in an object are not shown (default). If set to 
	*													true, userfunctions are rendered
	*
	*	@access		public
	* @version	0.2
	*/
	function introspection($title="", $data = "", $userfunction=true) {
		
		if (""==$data)
			$data = $this;
		
		printf('<table border="1" cellspacing="4" cellpadding="4" bordercolor="Silver">%s',
							$this->CR_HTML
						);	
						
		if (""!=$title)
			printf('<tr>%s<td colspan=4><b>%s</b></td>%s</tr>%s', 
								$this->CR_HTML,
								$title,
								$this->CR_HTML,
								$this->CR_HTML
							);
		
		reset($data);
		while (list($k, $v)=each($data)) {
		
			if ("user function"==gettype($v) && !$userfunction) 
				continue;
			
			if (is_array($v) || is_object($v)) {
				
				
				$color="navy";
					
				printf('<tr>
									<td align="left" valign="top">
										<font color="%s"><pre><b>%s</b></pre></font>
									</td>
									<td align="left" valign="top"><font color="%s"><pre>=></pre></font></td>
									<td align="left" valign="top" colspan=2>',
										$color,
										$k,
										$color,
										$v
								);
								
				$this->introspection("", $v, $userfunction);
					
				printf('</td>%s</tr>%s', $this->CR_HTML, $this->CR_HTML);
				
			}	else {
				
				$color="black";
					
				printf('<tr>
									<td align="left" valign="top">
										<font color="%s"><pre><b>%s</b></pre></font>
									</td>
									<td align="left" valign="top"><pre><font color="%s">=></pre></font></td>
									<td align="left" valign="top"><pre><font color="%s">[%s]</font></pre></td>
									<td align="left" valign="top"><pre><font color="%s">"%s"</font></pre></td>
								</tr>',
									$color,
									$k,
									$color,
									$color,
									gettype($v),
									$color,
									$v
								);
			}
		}
		print '</table>'.$this->CR_HTML;
		
	} // end func introspection
	
} // end class PhpdocObject
?>