<?php
/**
* Base of all exporter classes
* @author		Ulf Wendel <ulf@redsys.de>
* @version 	0.1alpha
* @since		0.2alpha
*/
class PhpdocExporterObject extends PhpdocObject {

	/**
	* String with the result of the export
	* @var	string	$result
	* @see	get()
	*/
	var $result = "";
	
	/**
	* Name of the file where the result is written to
	* @var	string	$targetFile
	* @see	setTargetFile()
	*/
	var $targetFile = "";

	/**
	* Flag indicating wheter to show status messages or not
	* @var	bool	$flagoutput	(default: false)
	* @see	MyOutl()
	*/
	var $flagOutput = false;
	
	/**
	* Shared Phpdoc FileHandler Object
	* @var	object	PhpdocFileHandler	$fileHandler
	* @see	PhpdocExporterObject()
	*/
	var $fileHandler = "";
	
	/**
	* Class tree
	* @var		array $classTree
	*/								
	var $classTree = array();				
	
	/**
	* Array mapping Classnames to Filenames
	* 
	* The array is indexed by the Classnames
	*
	* @var		array		$classnamesToFilenames
	*/
	var $classnamesToFilenames = array();
	
	/**
	* Parsing result. Array of all classes
	* @var		array		$classes
	*/
	var $classes = array();
	
	/**
	* Kind of a constructor, fills the object with data
	* @param	array	$classTree
	* @param	array	$classnamesToFilenames
	* @param	array	$classes
	* @return	bool	$ok
	* @throws	wrong_param
	* @see		fileHandler
	* @access	public
	*/
	function Setup($classTree, $classnamesToFilenames, $classes) {
		if (!is_array($classTree) || !is_array($classnamesToFilenames) || !is_array($classes)) {
			$this->err = new exeption_runtime_wrongparam("Illegal function call.", 1, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return false;
		}
	
		$this->fileHandler = new PhpdocFileHandler;
		
		$this->classTree 							= $classTree;
		$this->classnamesToFilenames	= $classnamesToFilenames;
		$this->classes 								= $classes;
		
		return true;
	} // end Setup
	
	/**
	* Starts the export process
	* @abstract
	* @access	public
  * @return boolean $ok
	*/
	function export() {
		die();
	} // end func export
	
	/**
	* Sets the output file of the exporter
	* @param	string	$targetFile
	* @return	bool 		$ok
	* @throws	wrong_param
	* @access	public
	*/
	function setTargetFile($targetFile) {
		if (""==$target) {
			$this->err = new exception_runtime_wrongparam("No target File specified.", 2, __FILE__, __LINE__, $this->AUTO_HANDLE_ERRORS);
			return false;
		}
		
		$this->targetFile = $targetFile;
		return true;
	} // end func setTargetFile
	
	/**
	* Sets the Output Flag
	* If set to true the Exporter prints some status messages
	* @param	bool	$flagOutput
	* @access	public
	* @see		flagOutput
	*/
	function setFlagOutput($flagOutput) {
		$flagOutput = ($flagOutput) ? true : false;
	} // end func setFlagOutput
	
  /**
	* Returns the output of the exporter
	* @return	string	$result
	* @access	public
	*/
	function get() {
		return $this->result;
	} // end func get
  
  /**
  * Saves the result to disk if a target file is given
  * @return boolean $ok
  * @access public
  */
  function saveResult() {
    if (""==$this->targetFile)
      return true;
     
    $fileHandler = new PhpdocFileHandler;
    $ok = $fileHandler->createFile($this->targetFile, $this->result);
    
    return $ok;
  } // end func saveResult
  
	/**
	* Wrapper to outl()
	* Prints the message if flagOutput it set to true
	* @brother outl()
	* @access	public
	*/
	function MyOutl($message) {
		if (false == $this->flagOutput)
			return;
		$this->outl($message);
	} // end func MyOutl

} // end class PhpdocExporterObject
?>