<?php
/**
* Looks for documented and undocumented functions within a block of php code
* @author	Ulf Wendel <ulf@redsys.de>
* @version 0.2
*/
class PhpdocFunctionParser extends PhpdocVariableParser {

  /**
  * Array of functions found in the given source code
	* 
	* The array is indexed by the functionname. See 
	* $emptyFunction to see the internal structure.
	*
  * @var    array $functions
  * @see		emptyFunction
  */
  var $functions = array();

	/**
	* Internal structur of a function
	* @var	array	$emptyFunction
	* @see	functions, analyseFunctionParagraph()
	*/
	var $emptyFunction = array(
															"name"					=> "",
															"shortdesc"			=> "",
															"desc"					=> "",
															"param"					=> array(),
															"return"				=> array(),
															"throws"				=> array(),
															"see"						=> array(),
															"access"				=> "",
															"version"				=> "",
															"since"					=> "",
															"abstract"			=> "",
															"static"				=> "",
															"brother"				=> "",
															"author"				=> "",
															"copyright"			=> "",
															"ignored"				=> array(),
															"undocumented"	=> ""
												);
		
	/**
	* Array of tags that are allowed in front of the function keyword
	* @var	array	$functionTags
	* @see	analyseFunctionParagraph()
	*/
	var $functionTags = array(
															"@param"			=> true,
															"@return"			=> true,
															"@throws"			=> true,
															"@see"				=> true,
															"@access"			=> true,
															"@version"		=> true,
															"@since"			=> true,
															"@abstract"		=> true,
															"@static"			=> true,
															"@brother"		=> true,
															"@author"			=> true,
															"@copyright"	=> true
											);
	
	/**
	* Just calls Setup()
	* @see	Setup()
	*/
	function PhpdocFunctionParser() {
		$this->Setup();
	} // end constructor
	
	/**
	* Function analyser.
	* @param	string	$phpcode	code to analyse
	* @param	array		$pargraphs
	* @return	array		$class
	* @throws	runtime
	* @access	public
	*/
	function analyseFunctions($phpcode) {
	
		$this->functions = array();
		
		$paragraphs = $this->getPhpdocParagraphs($phpcode, "functions");
		reset($paragraphs["functions"]);
		while (list($k, $paragraph)=each($paragraphs["functions"])) 
			$this->analyseFunctionParagraph($paragraph);

		$this->addUndocumentedFunctions($phpcode);			
		
		return $this->functions;
	} // end func analyseFunctions

	/**
	* Analyses a singe function paragraph and adds the result to the function instance variable
	* @param	array	$paragraph
	* @see		functions
	*/	
	function analyseFunctionParagraph($paragraph) {
		
		$function = $this->emptyFunction;
		
		$name	= $paragraph["regs"][2];
		$function["name"] = $name;
		
		list($shortdesc, $fulldesc) = $this->getDescription($paragraph["phpdoc"]);
		$function["shortdesc"] 	= $shortdesc;
		$function["desc"] 			= $fulldesc;
		
		$tags = $this->getTags($paragraph["phpdoc"]);
		$function = $this->analyseTags($tags, $function, $this->functionTags);
		
		$function["undocumented"] = false;
		
		$this->functions[$name] = $function;
		
	} // end func analyseFunctionParagraph
	
	/**
	* Looks for undocumented functions and add them to the parsing result
	* @param	string	$phpcode
	* @access	private
	*/
	function addUndocumentedFunctions($phpcode) {
		
		$regexp = "/". substr($this->PHP_FUNCTION, 2);
		preg_match_all($regexp, $phpcode, $paragraphs, PREG_SET_ORDER);
		
		reset($paragraphs);
		while (list($k, $paragraph)=each($paragraphs)) {
			if (!isset($this->functions[$paragraph[2]])) {
				$this->functions[$paragraph[2]] = $this->emptyFunction;
				$this->functions[$paragraph[2]]["name"] = $paragraph[2];
				$this->functions[$paragraph[2]]["undocumented"] = true;
			}
		}
				
	} // end func addUndocumentedFunctions
	
} // end class PhpdocFunctionParser
?>